/* SSL directory.  */
#undef ssldir

/* SSL config directory.  */
#undef sslcnf

/* Stunnel version.  */
#undef VERSION

/* Stunnel HOST.  */
#undef HOST

/* Define if you have the TCP wrapper library (-lwrap).  */
#undef HAVE_LIBWRAP

/* Define if your headers are in openssl/ directory.  */
#undef HAVE_OPENSSL

